function object = flt( arg )

% object = flt( input )
% object = flt( nchannels )
%
% This class provides these methods:
%   .get_nchannels()
%   .set_enabled()
%   .is_enabled()
%   .pop()
%
% If an input source is given, then the channel count is read directly
% from it. Also set_enabled() propagates directly to the input and pop()
% reads its results directly from the input.
%
% If only the channel count is given, then all methods except get_nchannels()
% should be overrided.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% define the class so that matlab recognizes it when loading objects
if nargin == 0
  this.enabled     = [];
  this.nchannels   = [];
  this.input       = [];
  this.nan_vals    = [];
  object = class( this, 'flt' );
  return;
end


if isa(arg, 'flt')
  nchannels = get_nchannels( arg );
  input     = arg;
else
  nchannels = arg;
  input     = [];
end


this.enabled     = 0;
this.nchannels   = nchannels;
this.input       = input;
this.nan_vals    = NaN * zeros( 1, this.nchannels );


object = class( this, 'flt' );
return;
