function status = wait_until_sysload_ok( this )



%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

status = 1;


% wait until system load is ok
retries = this.SAFECHECK_COUNT;
while retries > 0
  
  % read policy
  fid = fopen( [ this.commdir 'policy.txt'], 'rt' );
  if fid == -1, warning('Unable to open policy file!'); return; end
  policy = fscanf( fid, this.POLICY_FORMAT_STRING );
  fclose( fid );
  if length(policy) ~= length(find(strfind( this.POLICY_FORMAT_STRING, '%d' )))
    warning('Unable to parse the policy file!');
    return;
  end
  
  % deal policy entries
  minworkers      = policy(1);
  maxworkers      = policy(2);
  maxprocsrunning = policy(3);
  
  % read and parse the current system status
  [running, active_jobs, active_workers] = query_system( this );
  starting = active_jobs - active_workers;
  
  % check if ok
  if active_jobs < minworkers
    retries = 0;
  elseif active_jobs < maxworkers & running + starting < maxprocsrunning
    if maxprocsrunning - (running + starting) <= this.SAFECHECK_TOL
      retries = retries - 1;
      if retries > 0 & ~this.quiet
        fprintf( 'System load near limit, monitoring for a while..\n' );
      end
    else
      retries = 0;
    end
  else
    if ~this.quiet
      if active_jobs >= maxworkers
        fprintf( 'Maximum number of jobs active, delaying new jobs..\n' );
      else
        fprintf( 'System load too high, delaying new jobs..\n' );
      end
    end
    retries = this.SAFECHECK_COUNT;
  end
  
  % wait if not all ok
  if retries > 0
    system([ 'sleep ' num2str(this.poll_intv) ]);
    i = 1e6; while i, i=i-1; end
  end
  
end

status = 0;
return;
