function state = purge_state( state )

% For internal use only.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


% todo: When one exists, then use an user interface function to cleanup the
% 'group_models' field in a results struct.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% is a cell array of states or results?
if iscell( state )
  % purge recursively
  for i=1:length(state), state{i} = purge_state( state{i} ); end
  return;
end

% is an ivga() results struct?
if isfield( state, 'group_models' )
  % purge component models
  for i=1:length(state.group_models)
    % todo: use an appropriate user interface function here when one exists
    state.group_models(i).dataset_specifics.component_weights = [];
  end
  % handle the 'internal' field if one is still contained in the result
  if isfield( state, 'internal' )
    state.internal = purge_state( state.internal );
  end
  return;
end


% -- default case: 'state' is really an internal ivga() state --

% discard the dataset
state.data = [];

% compact the group cache
state.Groups = state.Groups(state.Ind);
state.Hash   = state.Hash(state.Ind);
state.Ind    = 1:length(state.Ind);

% purge models in group cache
for ind = 1:length(state.Groups)
  state.Groups(ind).Model = purge_dataset_specifics(state.Groups(ind).Model);
end

return;
